{
	"name" : "Analytic lines - Reporting",
	"version" : "1.0",
	"author" : "Tiny",
	"website" : "http://tinyerp.com",
	"depends" : ["account", "hr_timesheet_invoice"],
	"category" : "Generic Modules/Accounting",
	"description": "A report on analytic lines, costs by products, months and accounts.",
	"init_xml" : [],
	"demo_xml" : [
	],
	"update_xml" : [
		"report_analytic_line_view.xml",
	],
	"active": False,
	"installable": True
}
